@@ -3,7 +3,7 @@
  *
  * This file is part of msmtp, an SMTP client.
  *
- * Copyright (C) 2000, 2003, 2004, 2005, 2006, 2007, 2008
+ * Copyright (C) 2000, 2003, 2004, 2005, 2006, 2007, 2008, 2009
  * Martin Lambers <marlam@marlam.de>
  * Jay Soffian <jaysoffian@gmail.com> (Mac OS X keychain support)
  * Satoru SATOH <satoru.satoh@gmail.com> (GNOME keyring support)
@@ -38,26 +38,15 @@ extern char *optarg;
 extern int optind;
 #include <unistd.h>
 #include <sysexits.h>
+#include <netdb.h>
+#include <arpa/inet.h>
+#include <fcntl.h>
 #ifdef ENABLE_NLS
 # include <locale.h>
 #endif
 #ifdef HAVE_SYSLOG
 # include <syslog.h>
 #endif
-#ifdef W32_NATIVE
-# include <io.h>
-# include <fcntl.h>
-# include <windows.h>
-# include <winsock2.h>
-#elif defined DJGPP
-# include <io.h>
-# include <fcntl.h>
-# include <netdb.h>
-# include <arpa/inet.h>
-#else /* UNIX */
-# include <netdb.h>
-# include <arpa/inet.h>
-#endif
 #ifdef HAVE_GNOMEKEYRING
 # include <gnome-keyring.h>
 #endif
@@ -94,7 +83,7 @@ extern int optind;
 #else /* UNIX */
 #define SYSCONFFILE	"msmtprc"
 #define USERCONFFILE	".msmtprc"
-#define SYSNETRCFILE	".netrc"
+#define SYSNETRCFILE	"netrc"
 #define USERNETRCFILE	".netrc"
 #endif
 
@@ -877,12 +866,12 @@ int msmtp_serverinfo(account_t *acc, int debug, list_t **msg, char **errstr)
 		printf(_("%ld bytes"), srv.cap.size);
 		if (srv.cap.size > 1024 * 1024)
 		{
-		    printf(_(" = %.2f MB"), 
-			    (float)srv.cap.size / (1024.0 * 1024.0));
+		    printf(_(" = %.2f MiB"),
+			    (float)srv.cap.size / (float)(1024 * 1024));
 		}
 		else if (srv.cap.size > 1024)
 		{
-		    printf(_(" = %.2f KB"), (float)srv.cap.size / 1024.0);
+		    printf(_(" = %.2f KiB"), (float)srv.cap.size / 1024.0f);
 		}
 		printf("\n");
 	    }
@@ -2301,7 +2290,7 @@ void msmtp_print_version(void)
     free(userconffile);
     free(homedir);
     printf("\n");
-    printf(_("Copyright (C) 2008 Martin Lambers and others.\n"
+    printf(_("Copyright (C) 2009 Martin Lambers and others.\n"
 		"This is free software.  You may redistribute copies of "
 		    "it under the terms of\n"
 		"the GNU General Public License "
@@ -2576,6 +2565,7 @@ int msmtp_cmdline(msmtp_cmdline_conf_t *conf, int argc, char *argv[])
 		conf->pretend = 1;
 		break;
 		
+	    case 'v':
 	    case 'd':
 		conf->print_conf = 1;
 		conf->debug = 1;
@@ -3072,7 +3062,6 @@ int msmtp_cmdline(msmtp_cmdline_conf_t *conf, int argc, char *argv[])
 	    case 'n':
 	    case 'O':
 	    case 'o':
-	    case 'v':
 		break;
 		
 	    /* unknown option */
@@ -3123,6 +3112,7 @@ int msmtp_get_conffile_accounts(list_t **account_list,
     list_t *user_account_list;
     list_t *lps;
     list_t *lpu;
+    int securitycheck;
     int e;
 
 
@@ -3135,8 +3125,9 @@ int msmtp_get_conffile_accounts(list_t **account_list,
     system_confdir = get_sysconfdir();
     system_conffile = get_filename(system_confdir, SYSCONFFILE);
     free(system_confdir);
-    if ((e = get_conf(system_conffile, 0, &system_account_list, &errstr)) 
-	    != CONF_EOK)
+    securitycheck = 0;
+    if ((e = get_conf(system_conffile, securitycheck,
+                    &system_account_list, &errstr)) != CONF_EOK)
     {
 	if (e == CONF_ECANTOPEN)
 	{
@@ -3177,8 +3168,13 @@ int msmtp_get_conffile_accounts(list_t **account_list,
 	real_user_conffile = get_filename(homedir, USERCONFFILE);
 	free(homedir);
     }
-    if ((e = get_conf(real_user_conffile, 1, &user_account_list, &errstr)) 
-	    != CONF_EOK)
+#ifdef W32_NATIVE
+    securitycheck = 1;
+#else
+    securitycheck = (geteuid() != 0);
+#endif
+    if ((e = get_conf(real_user_conffile, securitycheck,
+                    &user_account_list, &errstr)) != CONF_EOK)
     {
 	if (e == CONF_ECANTOPEN)
 	{
@@ -3417,10 +3413,7 @@ int main(int argc, char *argv[])
 
     
     /* Avoid the side effects of text mode interpretations on DOS systems. */
-#ifdef W32_NATIVE
-    _setmode(_fileno(stdin), _O_BINARY);
-    _fmode = _O_BINARY;
-#elif defined DJGPP
+#if defined W32_NATIVE || defined DJGPP
     setmode(fileno(stdin), O_BINARY);
     _fmode = O_BINARY;
 #endif
@@ -3483,7 +3476,7 @@ int main(int argc, char *argv[])
 	    print_error("%s", msmtp_sanitize_string(errstr));
 	    goto exit;
 	}
-	if (fseek(tmpfile, 0L, SEEK_SET) != 0)
+	if (fseeko(tmpfile, 0, SEEK_SET) != 0)
 	{
 	    print_error(_("cannot rewind temporary file: %s"), 
 		    msmtp_sanitize_string(strerror(errno)));
