@@ -3,7 +3,7 @@
  *
  * This file is part of msmtp, an SMTP client.
  *
- * Copyright (C) 2000, 2003, 2004, 2005, 2006, 2007, 2008
+ * Copyright (C) 2000, 2003, 2004, 2005, 2006, 2007, 2008, 2009
  * Martin Lambers <marlam@marlam.de>
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -50,6 +50,11 @@
 # include <idna.h>
 #endif
 
+#if W32_NATIVE
+# include <sys/socket.h>
+# include "w32sock.h"
+#endif
+
 #include "gettext.h"
 #include "xalloc.h"
 #include "xvasprintf.h"
@@ -806,7 +811,7 @@ int tls_check_cert(tls_t *tls, const char *hostname, int verify, char **errstr)
     /* needed to get the common name: */
     X509_NAME *x509_subject;
     char *buf;
-    int bufsize;
+    int length;
     /* needed to get the DNS subjectAltNames: */
     STACK *subj_alt_names;
     int subj_alt_names_count;
@@ -868,6 +873,14 @@ int tls_check_cert(tls_t *tls, const char *hostname, int verify, char **errstr)
 	    subj_alt_name = sk_GENERAL_NAME_value(subj_alt_names, i);
 	    if (subj_alt_name->type == GEN_DNS) 
 	    {
+                if ((size_t)(subj_alt_name->d.ia5->length)
+                        != strlen((char *)(subj_alt_name->d.ia5->data)))
+                {
+                    *errstr = xasprintf(_("%s: certificate subject "
+                                "alternative name contains NUL"), error_msg);
+                    X509_free(x509cert);
+                    return TLS_ECERT;
+                }
 		if ((match_found = hostname_match(hostname_ascii, 
 				(char *)(subj_alt_name->d.ia5->data))))
 		{
@@ -886,12 +899,11 @@ int tls_check_cert(tls_t *tls, const char *hostname, int verify, char **errstr)
 	    X509_free(x509cert);
 	    return TLS_ECERT;
 	}
-	bufsize = X509_NAME_get_text_by_NID(x509_subject, NID_commonName, 
+	length = X509_NAME_get_text_by_NID(x509_subject, NID_commonName,
 		NULL, 0);
-	bufsize++;
-	buf = xmalloc((size_t)bufsize);
+	buf = xmalloc((size_t)length + 1);
 	if (X509_NAME_get_text_by_NID(x509_subject, NID_commonName, 
-		    buf, bufsize) == -1)
+		    buf, length + 1) == -1)
 	{
 	    *errstr = xasprintf(_("%s: cannot get certificate common name"),
 		    error_msg);
@@ -899,6 +911,14 @@ int tls_check_cert(tls_t *tls, const char *hostname, int verify, char **errstr)
 	    free(buf);
 	    return TLS_ECERT;
 	}
+        if ((size_t)length != strlen(buf))
+        {
+            *errstr = xasprintf(_("%s: certificate common name contains NUL"),
+                    error_msg);
+            X509_free(x509cert);
+            free(buf);
+            return TLS_ECERT;
+        }
 	match_found = hostname_match(hostname_ascii, buf);
 	free(buf);
     }
@@ -952,7 +972,7 @@ int tls_init(tls_t *tls,
 	    {
 		error_pos_str = xasprintf(
 			_("error in priority string at position %d"), 
-			error_pos - priorities + 1);
+			(int)(error_pos - priorities + 1));
 		*errstr = xasprintf(
 			_("cannot set priorities for TLS session: %s"),
 			error_pos_str);
@@ -1234,6 +1254,9 @@ int tls_start(tls_t *tls, int fd, const char *hostname, int no_certcheck,
 #ifdef HAVE_LIBGNUTLS
     int error_code;
     
+#if W32_NATIVE
+    fd = FD_TO_SOCKET(fd);
+#endif
     gnutls_transport_set_ptr(tls->session, (gnutls_transport_ptr_t)fd);
     if ((error_code = gnutls_handshake(tls->session)) < 0)
     {
@@ -1283,6 +1306,9 @@ int tls_start(tls_t *tls, int fd, const char *hostname, int no_certcheck,
 #ifdef HAVE_OPENSSL
     int error_code;
     
+#if W32_NATIVE
+    fd = FD_TO_SOCKET(fd);
+#endif
     if (!SSL_set_fd(tls->ssl, fd))
     {
 	*errstr = xasprintf(_("cannot set the file descriptor for TLS: %s"), 
